@@ -12,6 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from fc_functions_framework._cli import _cli
+from functions_framework._cli import _cli
 
 _cli(prog_name="python -m functions_framework")
